<?php
class MW_Portfolio_Specs_Module extends ET_Builder_Module 
{
	function init()
	{
		$this->name            = 'Portfolio Specs';
		$this->slug            = 'mw_Portfolio_Specs';
		$this->version         = '1.0.01';
	}

	function get_fields(){
		return [
			'title' => [
				'label' => 'Title',
				'type' => 'text',
				'description' => '',
			],
		];
	}
	
	// public function get_advanced_fields_config(){
	// 	$advanced_fields = [];
	// 	$advanced_fields['animation'] = FALSE;
	// 	$advanced_fields['background'] = [
	// 			'css'     => [
	// 				'main' => '%%order_class%%',
	// 			],
	// 			'options' => [
	// 				'background_color'  => array(
	// 					'default' => et_builder_accent_color(),
	// 				),
	// 				'background_position' => array(
	// 					'default' => 'center',
	// 				),
	// 				'parallax_method'     => array(
	// 					'default' => 'off',
	// 				),
	// 			]
	// 		];
	// 	$advanced_fields['fonts']['nav_link_active'] = [
	// 		'label' => "Nav Links:Active",
	// 		'css' => [
	// 			'main' => "{$this->main_css_element} nav li a.active ",
	// 		],
	// 		'line_height' => [
	// 			'default' => '2em',
	// 		],
	// 	];
	// 	return $advanced_fields;
	// }
	
	public function output_cloned_fields_in_ul( $post_id ) {
		// Replace 'fields' with the actual clone field name
		$clone_field_name = 'fields';
	
		// Get the value of the clone field for the current post
		$cloned_fields = acf_get_field( 'field_66f38ebba95b7', $post_id );
		$cloned_group = $cloned_fields["clone"][0];
		$cloned_fields = acf_get_fields( $cloned_group );		
	
		$result = []; // Initialize an array to hold the output
		
		// Loop through each field in the clone
		foreach ( $cloned_fields as $field ) {
			// Get the field value for the current post
			$value = get_field( $field['name'], $post_id );
			
			if ( empty( $value ) ) {
				continue; // Skip empty values
			}
			
			// Prepare the output structure
			$prefix = isset( $field['prepend'] ) ? esc_html( $field['prepend'] ) : '';
			$suffix = isset( $field['append'] ) ? esc_html( $field['append'] ) : '';
			
			$field_type = $field['type']; // Get the field type
		
			// Store field information
			if ( is_array( $value ) ) {
				$result[] = [
					'field_label' => esc_html( $field['label'] ),
					'field_value' => $value,
					'is_array'    => true, // Mark it as an array for handling in the output function
					'field_type'  => $field_type,
					'prepend'      => $prefix,
					'append'      => $suffix,
				];
			} else {
				$result[] = [
					'field_label' => esc_html( $field['label'] ),
					'field_value' => esc_html( $value ), // Include prefix and suffix
					'is_array'    => false, // Mark it as a single value
					'field_type'  => $field_type,
					'prepend'      => $prefix,
					'append'      => $suffix,
				];
			}
		}
		return $result; 
		
	}
	
	public function display_cloned_fields_as_dl( $cloned_fields ) {
		if ( empty( $cloned_fields ) ) {
			return '<p>No cloned fields available.</p>';
		}
	
		$output = '<dl>'; // Start the definition list
	
		foreach ( $cloned_fields as $field ) {
			$output .= '<dt>' . esc_html( $field['field_label'] ) . ':</dt>'; // Output the field label
			$output .= '<dd>'; // Start the definition description
			// Check field type and format accordingly
			if ( $field['field_type'] === 'text' ) {
				// Prepare the value with optional prepend/append
				$value = esc_html( $field['field_value'] );
				
				// Create a span for the value, including prepend and append if they have content
				$output .= '<span class="field-value">';
				if ( !empty( $field['prepend'] ) ) {
					$output .= '<span class="prepend">' . esc_html( $field['prepend'] ) . '</span>';
				}
				$output .= $value; // Output the main value
				if ( !empty( $field['append'] ) ) {
					$output .= '<span class="append">' . esc_html( $field['append'] ) . '</span>';
				}
				$output .= '</span>';
			} elseif ( $field['field_type'] === 'select' && $field['is_array'] ) {
				// Handle select field with multiple values
				foreach ( $field['field_value'] as $select_value ) {
					$output .= '<span class="field-value">' . esc_html( $select_value ) . '</span> ';
				}
			} else {
				// For other types, output value directly
				$output .= '<span class="field-value">' . esc_html( $field['field_value'] ) . '</span>';
			}
			$output .= '</dd>'; // End the definition description
		}
		$output .= '</dl>'; // End the definition list
	
		return $output; // Return the generated HTML
	}

	public function render($atts, $content, $render_slug)
	{
		$post_id = get_the_ID();
		$fields = $this->output_cloned_fields_in_ul( $post_id );
		$list = $this->display_cloned_fields_as_dl($fields);
		
		$title = $this->props['title'];
		if($title != ''){
			$title = "<h3>$title</h3>";
		}
		
		$output = sprintf(
			'<div %1$s class="%2$s et_pb_module" >
				%3$s
				%4$s
			</div>',
			$this->module_id(),
			$this->module_classname( $render_slug ),
			$title,
			$list
		);
		
		$current_directory_url = trailingslashit( wp_make_link_relative( get_template_directory_uri() . str_replace( get_template_directory(), '', __DIR__ ) ) );

		wp_enqueue_style('Portfolio_Specs', $current_directory_url.'/assets/Portfolio_Specs.css', [], $this->version);
		wp_enqueue_script('Portfolio_Specs', $current_directory_url.'/assets/Portfolio_Specs.js', [], $this->version);
		return do_shortcode($output);
	}
}

new MW_Portfolio_Specs_Module();